==> arrow-docs-0.7.3-sources.jar: com/example/domain/Employee$$optics.kt <==
package `com`.`example`.`domain`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `com`.`example`.`domain`.`Employee`.Companion.iso: arrow.optics.Iso<`com`.`example`.`domain`.`Employee`, arrow.core.Tuple2<`kotlin`.`String`, `com`.`example`.`domain`.`Company`?>> inline get()= arrow.optics.Iso(
  get = { employee: `com`.`example`.`domain`.`Employee` -> arrow.core.Tuple2(employee.`name`, employee.`company`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`String`, `com`.`example`.`domain`.`Company`?> -> `com`.`example`.`domain`.`Employee`(tuple.a, tuple.b) }
)

inline val `com`.`example`.`domain`.`Employee`.Companion.name: arrow.optics.Lens<`com`.`example`.`domain`.`Employee`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { employee: `com`.`example`.`domain`.`Employee` -> employee.`name` },
  set = { value: `kotlin`.`String` ->
    { employee: `com`.`example`.`domain`.`Employee` ->
      employee.copy(`name` = value)
    }
  }
)

inline val `com`.`example`.`domain`.`Employee`.Companion.nullableCompany: arrow.optics.Lens<`com`.`example`.`domain`.`Employee`, `com`.`example`.`domain`.`Company`?> inline get()= arrow.optics.Lens(
  get = { employee: `com`.`example`.`domain`.`Employee` -> employee.`company` },
  set = { value: `com`.`example`.`domain`.`Company`? ->
    { employee: `com`.`example`.`domain`.`Employee` ->
      employee.copy(`company` = value)
    }
  }
)


inline val `com`.`example`.`domain`.`Employee`.Companion.company: arrow.optics.Optional<`com`.`example`.`domain`.`Employee`, `com`.`example`.`domain`.`Company`> inline get()= arrow.optics.Optional(
  getOrModify = { employee: `com`.`example`.`domain`.`Employee` -> employee.`company`?.right() ?: employee.left() },
  set = { value: `com`.`example`.`domain`.`Company` ->
    { employee: `com`.`example`.`domain`.`Employee` ->
      employee.copy(`company` = value)
    }
  }
)

inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Employee`>.company: arrow.optics.Optional<S, `com`.`example`.`domain`.`Company`> inline get() = this + `com`.`example`.`domain`.`Employee`.company
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Employee`>.company: arrow.optics.Optional<S, `com`.`example`.`domain`.`Company`> inline get() = this + `com`.`example`.`domain`.`Employee`.company
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Employee`>.company: arrow.optics.Optional<S, `com`.`example`.`domain`.`Company`> inline get() = this + `com`.`example`.`domain`.`Employee`.company
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Employee`>.company: arrow.optics.Optional<S, `com`.`example`.`domain`.`Company`> inline get() = this + `com`.`example`.`domain`.`Employee`.company
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Employee`>.company: arrow.optics.Setter<S, `com`.`example`.`domain`.`Company`> inline get() = this + `com`.`example`.`domain`.`Employee`.company
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Employee`>.company: arrow.optics.Traversal<S, `com`.`example`.`domain`.`Company`> inline get() = this + `com`.`example`.`domain`.`Employee`.company
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Employee`>.company: arrow.optics.Fold<S, `com`.`example`.`domain`.`Company`> inline get() = this + `com`.`example`.`domain`.`Employee`.company

inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Employee`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Employee`.name
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Employee`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Employee`.name
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Employee`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Employee`.name
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Employee`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Employee`.name
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Employee`>.name: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Employee`.name
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Employee`>.name: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Employee`.name
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Employee`>.name: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Employee`.name
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Employee`>.name: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Employee`.name

inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Employee`>.nullableCompany: arrow.optics.Lens<S, `com`.`example`.`domain`.`Company`?> inline get() = this + `com`.`example`.`domain`.`Employee`.nullableCompany
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Employee`>.nullableCompany: arrow.optics.Lens<S, `com`.`example`.`domain`.`Company`?> inline get() = this + `com`.`example`.`domain`.`Employee`.nullableCompany
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Employee`>.nullableCompany: arrow.optics.Optional<S, `com`.`example`.`domain`.`Company`?> inline get() = this + `com`.`example`.`domain`.`Employee`.nullableCompany
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Employee`>.nullableCompany: arrow.optics.Optional<S, `com`.`example`.`domain`.`Company`?> inline get() = this + `com`.`example`.`domain`.`Employee`.nullableCompany
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Employee`>.nullableCompany: arrow.optics.Getter<S, `com`.`example`.`domain`.`Company`?> inline get() = this + `com`.`example`.`domain`.`Employee`.nullableCompany
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Employee`>.nullableCompany: arrow.optics.Setter<S, `com`.`example`.`domain`.`Company`?> inline get() = this + `com`.`example`.`domain`.`Employee`.nullableCompany
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Employee`>.nullableCompany: arrow.optics.Traversal<S, `com`.`example`.`domain`.`Company`?> inline get() = this + `com`.`example`.`domain`.`Employee`.nullableCompany
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Employee`>.nullableCompany: arrow.optics.Fold<S, `com`.`example`.`domain`.`Company`?> inline get() = this + `com`.`example`.`domain`.`Employee`.nullableCompany

==> arrow-docs-0.10.3-sources.jar: com/example/domain/Employee$$optics.kt <==
package `com`.`example`.`domain`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `com`.`example`.`domain`.`Employee`.Companion.iso: arrow.optics.Iso<`com`.`example`.`domain`.`Employee`, arrow.core.Tuple2<`kotlin`.`String`, `com`.`example`.`domain`.`Company`?>> inline get()= arrow.optics.Iso(
  get = { employee: `com`.`example`.`domain`.`Employee` -> arrow.core.Tuple2(employee.`name`, employee.`company`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`String`, `com`.`example`.`domain`.`Company`?> -> `com`.`example`.`domain`.`Employee`(tuple.a, tuple.b) }
)

inline val `com`.`example`.`domain`.`Employee`.Companion.name: arrow.optics.Lens<`com`.`example`.`domain`.`Employee`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { employee: `com`.`example`.`domain`.`Employee` -> employee.`name` },
  set = { employee: `com`.`example`.`domain`.`Employee`, value: `kotlin`.`String` -> employee.copy(`name` = value) }
)

inline val `com`.`example`.`domain`.`Employee`.Companion.nullableCompany: arrow.optics.Lens<`com`.`example`.`domain`.`Employee`, `com`.`example`.`domain`.`Company`?> inline get()= arrow.optics.Lens(
  get = { employee: `com`.`example`.`domain`.`Employee` -> employee.`company` },
  set = { employee: `com`.`example`.`domain`.`Employee`, value: `com`.`example`.`domain`.`Company`? -> employee.copy(`company` = value) }
)


inline val `com`.`example`.`domain`.`Employee`.Companion.company: arrow.optics.Optional<`com`.`example`.`domain`.`Employee`, `com`.`example`.`domain`.`Company`> inline get()= arrow.optics.Optional(
  getOrModify = { employee: `com`.`example`.`domain`.`Employee` -> employee.`company`?.right() ?: employee.left() },
  set = { employee: `com`.`example`.`domain`.`Employee`, value: `com`.`example`.`domain`.`Company` -> employee.copy(`company` = value) }
)

inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Employee`>.company: arrow.optics.Optional<S, `com`.`example`.`domain`.`Company`> inline get() = this + `com`.`example`.`domain`.`Employee`.company
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Employee`>.company: arrow.optics.Optional<S, `com`.`example`.`domain`.`Company`> inline get() = this + `com`.`example`.`domain`.`Employee`.company
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Employee`>.company: arrow.optics.Optional<S, `com`.`example`.`domain`.`Company`> inline get() = this + `com`.`example`.`domain`.`Employee`.company
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Employee`>.company: arrow.optics.Optional<S, `com`.`example`.`domain`.`Company`> inline get() = this + `com`.`example`.`domain`.`Employee`.company
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Employee`>.company: arrow.optics.Setter<S, `com`.`example`.`domain`.`Company`> inline get() = this + `com`.`example`.`domain`.`Employee`.company
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Employee`>.company: arrow.optics.Traversal<S, `com`.`example`.`domain`.`Company`> inline get() = this + `com`.`example`.`domain`.`Employee`.company
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Employee`>.company: arrow.optics.Fold<S, `com`.`example`.`domain`.`Company`> inline get() = this + `com`.`example`.`domain`.`Employee`.company

inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Employee`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Employee`.name
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Employee`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Employee`.name
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Employee`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Employee`.name
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Employee`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Employee`.name
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Employee`>.name: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Employee`.name
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Employee`>.name: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Employee`.name
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Employee`>.name: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Employee`.name
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Employee`>.name: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `com`.`example`.`domain`.`Employee`.name

inline val <S> arrow.optics.Iso<S, `com`.`example`.`domain`.`Employee`>.nullableCompany: arrow.optics.Lens<S, `com`.`example`.`domain`.`Company`?> inline get() = this + `com`.`example`.`domain`.`Employee`.nullableCompany
inline val <S> arrow.optics.Lens<S, `com`.`example`.`domain`.`Employee`>.nullableCompany: arrow.optics.Lens<S, `com`.`example`.`domain`.`Company`?> inline get() = this + `com`.`example`.`domain`.`Employee`.nullableCompany
inline val <S> arrow.optics.Optional<S, `com`.`example`.`domain`.`Employee`>.nullableCompany: arrow.optics.Optional<S, `com`.`example`.`domain`.`Company`?> inline get() = this + `com`.`example`.`domain`.`Employee`.nullableCompany
inline val <S> arrow.optics.Prism<S, `com`.`example`.`domain`.`Employee`>.nullableCompany: arrow.optics.Optional<S, `com`.`example`.`domain`.`Company`?> inline get() = this + `com`.`example`.`domain`.`Employee`.nullableCompany
inline val <S> arrow.optics.Getter<S, `com`.`example`.`domain`.`Employee`>.nullableCompany: arrow.optics.Getter<S, `com`.`example`.`domain`.`Company`?> inline get() = this + `com`.`example`.`domain`.`Employee`.nullableCompany
inline val <S> arrow.optics.Setter<S, `com`.`example`.`domain`.`Employee`>.nullableCompany: arrow.optics.Setter<S, `com`.`example`.`domain`.`Company`?> inline get() = this + `com`.`example`.`domain`.`Employee`.nullableCompany
inline val <S> arrow.optics.Traversal<S, `com`.`example`.`domain`.`Employee`>.nullableCompany: arrow.optics.Traversal<S, `com`.`example`.`domain`.`Company`?> inline get() = this + `com`.`example`.`domain`.`Employee`.nullableCompany
inline val <S> arrow.optics.Fold<S, `com`.`example`.`domain`.`Employee`>.nullableCompany: arrow.optics.Fold<S, `com`.`example`.`domain`.`Company`?> inline get() = this + `com`.`example`.`domain`.`Employee`.nullableCompany
